@@ -11,7 +11,9 @@ MainWindow::MainWindow(QWidget *parent) :
     ui->setupUi(this);
 settings=new QSettings();
 bios_path=settings->value("bios_path","/home/user/MyDocs/").toString();
+if (bios_path.right(1)!="/")bios_path+="/";
  rom_path=settings->value("rom_path","/home/user/MyDocs/").toString();
+ if (rom_path.right(1)!="/")rom_path+="/";
 
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     cfg=new options(this);
@@ -121,6 +123,7 @@ void MainWindow::set_rom_dir(){
 void MainWindow::set_bios_dir(){
     QString dir=QFileDialog::getExistingDirectory(this,tr("BIOS Directory"),"/home/user/MyDocs/");
     QString bios_path=dir;
+    if (bios_path.right(1)!="/")bios_path+="/";
     settings->setValue("bios_path",bios_path);
 
 
